@@ -279,12 +279,15 @@ EOH
         validations => {
             'tsrange' => $tsrange_validation,
         },
-        description => 'Get a list of holidays that fall within the given tsrange',
+        description => 'Determine holidays and weekends within a tsrange',
         documentation => <<'EOH',
 =pod
 
-This resource takes a tsrange and returns a list of holidays (dates) that 
-fall within that tsrange.
+Used with GET. For a given tsrange, return an object keyed on dates. The for
+each date key is itself an object. If a date falls on a weekend, the value will
+contain a subobject { "weekend": true }. If a date is a holiday, it will
+contain a subobject { "holiday": true }. If a date is neither a weekend nor a
+holiday, the value will be an empty object.
 EOH
     },
 
@@ -2190,19 +2193,10 @@ The request body takes the following parameters:
 
 =item * C<datelist> (a list of dates to create intervals for)
 
-=item * C<dry_run> (boolean value)
-
-=item * C<aid> (the AID of the activity; alternatively, C<code>)
-
-=item * C<long_desc> (optional interval description)
-
-=item * C<remark> (optional remark)
-
 =back
 
 If C<tsrange> is provided, C<datelist> should be omitted - and vice versa.
 
-If C<dry_run> is true, the resource does not change the database state.
 EOH
     },
 
